@@ -16,7 +16,7 @@
 
 static void IOP_profile_free (IOP_Profile_info *p);
 
-#ifdef LINC_SSL_SUPPORT
+#ifdef LINK_SSL_SUPPORT
 static IOP_Component_info *
 IOP_component_find (GSList *list, IOP_ComponentId type, GSList **pos)
 {
@@ -29,7 +29,7 @@ IOP_component_find (GSList *list, IOP_ComponentId type, GSList **pos)
 
   return NULL;
 }
-#endif /* LINC_SSL_SUPPORT */
+#endif /* LINK_SSL_SUPPORT */
 
 static gchar *
 IOP_ObjectKey_dump (ORBit_ObjectKey *objkey)
@@ -38,7 +38,7 @@ IOP_ObjectKey_dump (ORBit_ObjectKey *objkey)
 	GString *str = g_string_sized_new (objkey->_length * 2 + 4);
 
 	for (i = 0; i < objkey->_length; i++)
-		g_string_append_printf (str, "%2x", objkey->_buffer [i]);
+		g_string_append_printf (str, "%02x", objkey->_buffer [i]);
 
 	return g_string_free (str, FALSE);
 }
@@ -61,7 +61,8 @@ IOP_profile_dump (CORBA_Object obj, gpointer p)
 		key = IOP_ObjectKey_dump (obj->object_key);
 		g_string_printf (str, "P-IIOP %s:0x%x '%s'",
 				 iiop->host, iiop->port, key);
-		break;
+		g_free (key);
+ 		break;
 	}
 	
 	case IOP_TAG_GENERIC_IOP: {
@@ -82,6 +83,8 @@ IOP_profile_dump (CORBA_Object obj, gpointer p)
 		g_string_printf (str, "P-OS %s:0x%x '%s'",
 				 os->unix_sock_path, os->ipv6_port,
 				 key);
+
+		g_free (key);
 		break;
 	}
 	case IOP_TAG_MULTIPLE_COMPONENTS:
@@ -90,8 +93,6 @@ IOP_profile_dump (CORBA_Object obj, gpointer p)
 		break;
 	}
 
-	g_free (key);
-	
 	return g_string_free (str, FALSE);
 }
 
@@ -229,7 +230,7 @@ IOP_profile_get_info (CORBA_Object  obj,
       *host = iiop->host;
       *service = tmpbuf;
       g_snprintf(tmpbuf, 8, "%d", iiop->port);
-#ifdef LINC_SSL_SUPPORT
+#ifdef LINK_SSL_SUPPORT
       {
 	IOP_TAG_SSL_SEC_TRANS_info *ssli;
 	ssli = (IOP_TAG_SSL_SEC_TRANS_info *)
@@ -249,7 +250,7 @@ IOP_profile_get_info (CORBA_Object  obj,
       *proto = giop->proto;
       *host = giop->host;
       *service = giop->service;
-#ifdef LINC_SSL_SUPPORT
+#ifdef LINK_SSL_SUPPORT
       {
 	IOP_TAG_GENERIC_SSL_SEC_TRANS_info *ssli;
 	ssli = (IOP_TAG_GENERIC_SSL_SEC_TRANS_info *)
@@ -358,6 +359,9 @@ IOP_profile_equal (CORBA_Object obj1, CORBA_Object obj2,
 
 		if (strcmp (iiop1->host, iiop2->host))
 			return FALSE;
+
+		/* FIXME, also compare ssl ports */ 
+
 		break;
 	}
 
@@ -478,14 +482,14 @@ IOP_start_profiles (CORBA_ORB orb)
 	IOP_TAG_INTERNET_IOP_info        *iiop = NULL;
 
 	for (l = orb->servers ; l != NULL ; l = l->next) {
-		LINCServer *serv = l->data;
+		LinkServer *serv = l->data;
 		gboolean   ipv4, ipv6, uds, ssl;
 
 		ipv4 = !strcmp (serv->proto->name, "IPv4");
 		ipv6 = !strcmp (serv->proto->name, "IPv6");
 		uds  = !strcmp (serv->proto->name, "UNIX");
 
-		ssl  = (serv->create_options & LINC_CONNECTION_SSL);
+		ssl  = (serv->create_options & LINK_CONNECTION_SSL);
 
 		if (!osi && uds) {
 			osi = g_new0 (IOP_TAG_ORBIT_SPECIFIC_info, 1);
